nsavi: Calculate nSAVI

Description Usage Arguments Value

View source: R/ndvi.R

Description

This function caculates the normalized difference vegetation index.

Usage

1
nsavi(b1, b2, L = 0.5)

Arguments

b1

value or vector with reflectance in the first (eg. NIR for NDVI) wavelenght

b2

value or vector with reflectance in the second (eg. red for NDVI) wavelenght

L

soil coefficient. Set to 0.5 by default

Value

NDVI value


rmmarcos/pruebapaquete documentation built on Jan. 12, 2022, 12:26 a.m.